package com.emato.cus.supervise.config.ds.second;

import com.emato.cus.supervise.util.YmlUtils;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.SqlSessionTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.jdbc.DataSourceProperties;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.PropertyResolver;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;
import org.springframework.transaction.annotation.EnableTransactionManagement;

import javax.sql.DataSource;

/**
 * 多数据源配置
 *
 * 数据源配置
 *
 * 指定mybatis-config.xml, 和要扫描的别名包
 *
 * @author Scott Chen
 * @date 2017/4/22
 */
@EnableTransactionManagement(order = 2)
@Configuration
public class SecondDataSourceConfig {

    @Autowired
    private SecondMybatisConfigProperties secondMybatisConfigProperties;

    // -------------------- mybatis 属性配置 --------------------

    @Bean
    @ConfigurationProperties(prefix = "mybatis.second")
    public SecondMybatisConfigProperties secondMybatisConfigProperties(){
        return new SecondMybatisConfigProperties();
    }


    // -------------------- 其它业务库 --------------------


    @Bean
    public DataSource secondDataSource() {
        return secondDataSourceProperties().initializeDataSourceBuilder().build();
    }

    @Bean
    @ConfigurationProperties(prefix = "spring.datasource.second")
    public DataSourceProperties secondDataSourceProperties() {
        return new DataSourceProperties();
    }

    @Bean
    public SqlSessionFactory secondSqlSessionFactory(DataSource secondDataSource) throws Exception  {
        SqlSessionFactoryBean sessionFactoryBean = new SqlSessionFactoryBean();
        sessionFactoryBean.setDataSource(secondDataSource);

        sessionFactoryBean.setConfigLocation(new PathMatchingResourcePatternResolver().getResource(secondMybatisConfigProperties.getConfigLocation()));
        sessionFactoryBean.setMapperLocations(new PathMatchingResourcePatternResolver().getResources(secondMybatisConfigProperties.getMapperLocationsConfig()));
        sessionFactoryBean.setTypeAliasesPackage(secondMybatisConfigProperties.getTypeAliasesPackage());

        return sessionFactoryBean.getObject();
    }

    @Bean
    public DataSourceTransactionManager secondTransactionManager(DataSource secondDataSource) {
        return new DataSourceTransactionManager(secondDataSource);
    }

    @Bean
    public SqlSessionTemplate secondSqlSessionTemplate(SqlSessionFactory secondSqlSessionFactory) {
        return new SqlSessionTemplate(secondSqlSessionFactory);
    }

}
